@@ -14,7 +14,7 @@ class ccdf_market_rate(Variable):
         child_age_group = person("ccdf_age_group", period)
         duration_of_care = person("ccdf_duration_of_care", period)
         durations_of_care = duration_of_care.possible_values
-        market_rate_mapping = parameters(period).hhs.ccdf.amount
+        market_rate_mapping = parameters(period).gov.hhs.ccdf.amount
         rate_per_period = market_rate_mapping[county_cluster][
             provider_type_group
         ][duration_of_care][child_age_group]
