@@ -13,7 +13,7 @@ class snap_standard_deduction(Variable):
     def formula(spm_unit, period, parameters):
         standard_deductions = parameters(
             period
-        ).usda.snap.income.deductions.standard
+        ).gov.usda.snap.income.deductions.standard
         state_group = spm_unit.household("state_group_str", period)
         capped_household_size = min_(spm_unit("spm_unit_size", period), 6)
         return (
